package com.datacloudsec.response;

import com.datacloudsec.response.JsonResponse;
import com.datacloudsec.utils.JsonUtil;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import org.apache.commons.lang.StringUtils;

public class TreegridResponse extends JsonResponse {

   public TreegridResponse(List data, String parentFieldName, String ... parentKey) {
      this(data.size(), data, parentFieldName, parentKey);
   }

   public TreegridResponse(int total, List data, String parentFieldName, String ... parentKey) {
      super(true);
      super.putObj("total", Integer.valueOf(total));
      super.putObj("rows", createChilds(data, parentKey, 0, parentFieldName));
   }

   private static List createChilds(List data, String[] parentKey, int parentKeyIndex, String parentFieldName) {
      ArrayList newData = new ArrayList();

      while(data.size() > 0) {
         Map row = (Map)data.get(0);
         String type = (String)row.get(parentKey[parentKeyIndex]);
         if(StringUtils.isBlank(type)) {
            newData.add(row);
            data.remove(0);
         } else {
            List childs = findChilds(data, parentKey, parentKeyIndex, type, parentFieldName);
            HashMap map = new HashMap();
            map.put(parentFieldName, type);
            map.put("childs", childs);
            newData.add(map);
         }
      }

      return newData;
   }

   private static List findChilds(List data, String[] parentKey, int parentKeyIndex, String parentText, String parentFieldName) {
      if(parentKeyIndex >= parentKey.length) {
         return null;
      } else {
         ArrayList childs = new ArrayList();
         Iterator ite = data.iterator();

         while(ite.hasNext()) {
            Map row = (Map)ite.next();
            String type = (String)row.get(parentKey[parentKeyIndex]);
            if(type != null && type.equalsIgnoreCase(parentText)) {
               childs.add(row);
               ite.remove();
            }
         }

         if(parentKeyIndex + 1 >= parentKey.length) {
            return childs;
         } else {
            return createChilds(childs, parentKey, parentKeyIndex + 1, parentFieldName);
         }
      }
   }

   public static void main(String[] args) throws Exception {
      ArrayList data = new ArrayList();
      data.add(new HashMap() {

         private static final long serialVersionUID = 1L;

         {
            this.put("add1", "四川");
            this.put("add2", "遂宁");
            this.put("add3", "蓬溪");
            this.put("name", "aaaaaaaaaa");
         }
      });
      data.add(new HashMap() {

         private static final long serialVersionUID = 1L;

         {
            this.put("add1", "四川");
            this.put("add2", "遂宁");
            this.put("add3", "蓬溪");
            this.put("name", "bbbbbbb");
         }
      });
      data.add(new HashMap() {

         private static final long serialVersionUID = 1L;

         {
            this.put("add1", "四川");
            this.put("add2", "遂宁");
            this.put("name", "cccc");
         }
      });
      data.add(new HashMap() {

         private static final long serialVersionUID = 1L;

         {
            this.put("add1", "浙江");
            this.put("name", "ddddd");
         }
      });
      data.add(new HashMap() {

         private static final long serialVersionUID = 1L;

         {
            this.put("name", "eeeee");
         }
      });
      String[] parentKey = new String[]{"add1", "add2", "add3"};
      List newData = createChilds(data, parentKey, 0, "name");
      System.out.println(JsonUtil.MAPPER.writeValueAsString(newData));
   }
}
